@@ -4,9 +4,6 @@ import matplotlib   as _mpl
 import pylab
 
 
-# Version
-__version__ = '3.3.1'
-
 # Try to run the qt magic first
 try:
     if not pylab.get_backend()[0:2] == 'Qt':
@@ -30,6 +27,9 @@ settings = _settings.settings()
 fun._settings  = settings
 data._settings = settings
 
+# Get the version
+exec(fun.read_lines(_os.path.join(__path__[0],'setup.py'))[0])
+
 
 def _warn(*args):
     if settings['ignore_warnings']: return
